Learn R Programming

corrViz (version 0.1.0)

corrCircle: corrCircle

Description

This function creates a circular plot of correlations between variables in a dataset.

Usage

corrCircle(mat, threshold = 0, ticks = FALSE)

Value

A circular chord plot object displaying the correlations between variables.

Arguments

mat

A square correlation matrix to visualise.

threshold

A numeric value indicating the minimum absolute correlation value to display in the plot.

ticks

A logical value indicating whether to display ticks (TRUE) or not (FALSE), default is FALSE.

Details

When using a large amount of data, this plot can quickly become over complicated. It is recommended to filter the correlations using the threshold argument to simplify the visualisation.

Examples

Run this code
cm <- cor(mtcars)

corrCircle(mat = cm,
          threshold = 0.8)


Run the code above in your browser using DataLab