This function creates a chord plot of correlations between variables in a dataset.
Usage
corrChord(mat, threshold = 0, circle = FALSE)
Value
A chord plot displaying correlations.
Arguments
mat
A square correlation matrix to visualise.
threshold
A numeric value indicating the minimum absolute
correlation value to display in the plot.
circle
A logical value indicating whether to use a circular
layout (TRUE) or linear layout (FALSE), default is FALSE.
Details
When using a large amount of data, this plot can quickly become over
complicated. It is recommended to filter the correlations using the threshold
argument to simplify the visualisation.