powered by
This function creates an interactive heatmap of correlations between variables in a dataset.
corrHeatmap( mat, display = c("all", "upper", "lower"), reorder = TRUE, pal = colorRampPalette(c("darkblue", "white", "darkred"))(100) )
An interactive heatmap plot displaying correlations.
A square correlation matrix to visualise.
A character vector specifying which part of the correlation matrix to display: 'all', 'upper', or 'lower', default is 'all'.
A logical value indicating whether to reorder the heatmap based on hierarchical clustering, default is TRUE.
A color palette for the heatmap.
Creates an interactive heatmap displaying correlation values. By hovering mouse over a cell, the variables and correlation value is shown.
cm <- cor(mtcars) corrHeatmap(mat = cm, display = 'all')
Run the code above in your browser using DataLab