Learn R Programming

corrViz (version 0.1.0)

corrNetwork: corrNetwork

Description

Creates an interactive Correlation Network Visualization

Usage

corrNetwork(
  mat,
  threshold = 0,
  layout = "layout_nicely",
  width = "100%",
  height = "400px",
  physics = TRUE
)

Value

A network plot displaying correlations.

Arguments

mat

A square correlation matrix to visualise.

threshold

A numeric value indicating the minimum absolute correlation value to display in the plot.

layout

Any igraph layout to display the network.

width

The width of the viewing window.

height

The height of the viewing window.

physics

A logical value indicating whether to use physics-based layout. Default is TRUE.

Details

Each node in the network represents a variable where the width of the connecting edges represent the absolute value of the correlation. Positive correlations have red coloured edges whereas negative correlations have blue coloured edges.

Examples

Run this code
ci <- cor(iris[1:4])
corrNetwork(mat = ci, threshold = 0.5)

# Another example
cm <- cor(mtcars)

corrNetwork(mat = cm,
           threshold = 0.8,
           layout = 'layout_on_grid',
           physics = FALSE)

Run the code above in your browser using DataLab